# Scikit-Learn runtime for MLServer

This package provides a MLServer runtime compatible with Scikit-Learn.

## Usage

You can install the runtime, alongside `mlserver`, as:

```bash
pip install mlserver mlserver-sklearn
```

For further information on how to use MLServer with Scikit-Learn, you can check
out this [worked out example](../../examples/sklearn/README.md).
